==> jc-1.4.0.tar.gz: soot/dava/internal/javaRep/DIdentityStmt.h <==
// public class soot.dava.internal.javaRep.DIdentityStmt

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class 61e9bebcb9b9cd64 soot_dava_internal_javaRep_DIdentityStmt
// @dep_class 14819393b9272047 soot_grimp_internal_GIdentityStmt
// @dep_class edca39c912a872fb soot_jimple_internal_AbstractDefinitionStmt
// @dep_class b3c0d2cd30f6acdd soot_jimple_internal_AbstractStmt
// @dep_class b38b5e2548c0bae9 soot_jimple_internal_JIdentityStmt
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_grimp_internal_GIdentityStmt

#include "soot/grimp/internal/GIdentityStmt.h"

#ifndef _JC_soot_dava_internal_javaRep_DIdentityStmt_H_
#define _JC_soot_dava_internal_javaRep_DIdentityStmt_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_dava_internal_javaRep_DIdentityStmt$sub_refs	_jc_soot_dava_internal_javaRep_DIdentityStmt$sub_refs;
typedef struct _jc_soot_dava_internal_javaRep_DIdentityStmt$sub_nonrefs	_jc_soot_dava_internal_javaRep_DIdentityStmt$sub_nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DIdentityStmt$refs	_jc_soot_dava_internal_javaRep_DIdentityStmt$refs;
typedef struct _jc_soot_dava_internal_javaRep_DIdentityStmt$nonrefs	_jc_soot_dava_internal_javaRep_DIdentityStmt$nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DIdentityStmt$object	_jc_soot_dava_internal_javaRep_DIdentityStmt$object;

typedef const struct _jc_soot_dava_internal_javaRep_DIdentityStmt$vmethods	_jc_soot_dava_internal_javaRep_DIdentityStmt$vmethods;
typedef const struct _jc_soot_dava_internal_javaRep_DIdentityStmt$vtable	_jc_soot_dava_internal_javaRep_DIdentityStmt$vtable;
typedef const struct _jc_soot_dava_internal_javaRep_DIdentityStmt$vtype	_jc_soot_dava_internal_javaRep_DIdentityStmt$vtype;

// Constructors
extern void _jc_soot_dava_internal_javaRep_DIdentityStmt$method$_init$b3c9ec81c7d0a5b0(_jc_env *, struct _jc_soot_dava_internal_javaRep_DIdentityStmt$object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_dava_internal_javaRep_DIdentityStmt$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_dava_internal_javaRep_DIdentityStmt$object *);
extern void _jc_soot_dava_internal_javaRep_DIdentityStmt$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_dava_internal_javaRep_DIdentityStmt$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_javaRep_DIdentityStmt$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_dava_internal_javaRep_DIdentityStmt$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_dava_internal_javaRep_DIdentityStmt$vmethods {
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DIdentityStmt$object *);
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DIdentityStmt$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_dava_internal_javaRep_DIdentityStmt$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_jimple_internal_AbstractStmt$vmethods	soot_jimple_internal_AbstractStmt;
	_jc_soot_jimple_internal_AbstractDefinitionStmt$vmethods	soot_jimple_internal_AbstractDefinitionStmt;
	_jc_soot_jimple_internal_JIdentityStmt$vmethods	soot_jimple_internal_JIdentityStmt;
	_jc_soot_grimp_internal_GIdentityStmt$vmethods	soot_grimp_internal_GIdentityStmt;
	_jc_soot_dava_internal_javaRep_DIdentityStmt$vmethods	soot_dava_internal_javaRep_DIdentityStmt;
};

// Vtype
struct _jc_soot_dava_internal_javaRep_DIdentityStmt$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_javaRep_DIdentityStmt$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DIdentityStmt$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DIdentityStmt$refs {
    _jc_soot_dava_internal_javaRep_DIdentityStmt$sub_refs	soot_dava_internal_javaRep_DIdentityStmt;
    _jc_soot_grimp_internal_GIdentityStmt$sub_refs	soot_grimp_internal_GIdentityStmt;
    _jc_soot_jimple_internal_JIdentityStmt$sub_refs	soot_jimple_internal_JIdentityStmt;
    _jc_soot_jimple_internal_AbstractDefinitionStmt$sub_refs	soot_jimple_internal_AbstractDefinitionStmt;
    _jc_soot_jimple_internal_AbstractStmt$sub_refs	soot_jimple_internal_AbstractStmt;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DIdentityStmt$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DIdentityStmt$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_jimple_internal_AbstractStmt$sub_nonrefs	soot_jimple_internal_AbstractStmt;
    _jc_soot_jimple_internal_AbstractDefinitionStmt$sub_nonrefs	soot_jimple_internal_AbstractDefinitionStmt;
    _jc_soot_jimple_internal_JIdentityStmt$sub_nonrefs	soot_jimple_internal_JIdentityStmt;
    _jc_soot_grimp_internal_GIdentityStmt$sub_nonrefs	soot_grimp_internal_GIdentityStmt;
    _jc_soot_dava_internal_javaRep_DIdentityStmt$sub_nonrefs	soot_dava_internal_javaRep_DIdentityStmt;
};

// Object instance structure
struct _jc_soot_dava_internal_javaRep_DIdentityStmt$object {
	_jc_soot_dava_internal_javaRep_DIdentityStmt$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_javaRep_DIdentityStmt$vtype	*vtype;
	_jc_soot_dava_internal_javaRep_DIdentityStmt$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_javaRep_DIdentityStmt$vtype _jc_soot_dava_internal_javaRep_DIdentityStmt$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_javaRep_DIdentityStmt, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_javaRep_DIdentityStmt$class_object;

#endif	/* _JC_soot_dava_internal_javaRep_DIdentityStmt_H_ */

==> jc-1.4.6.tar.gz: soot/dava/internal/javaRep/DIdentityStmt.h <==
// public class soot.dava.internal.javaRep.DIdentityStmt

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class 61e9bebcb9b9cd64 soot_dava_internal_javaRep_DIdentityStmt
// @dep_class 14819393b9272047 soot_grimp_internal_GIdentityStmt
// @dep_class edca39c912a872fb soot_jimple_internal_AbstractDefinitionStmt
// @dep_class b3c0d2cd30f6acdd soot_jimple_internal_AbstractStmt
// @dep_class b38b5e2548c0bae9 soot_jimple_internal_JIdentityStmt
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_grimp_internal_GIdentityStmt

#include "soot/grimp/internal/GIdentityStmt.h"

#ifndef _JC_soot_dava_internal_javaRep_DIdentityStmt_H_
#define _JC_soot_dava_internal_javaRep_DIdentityStmt_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_dava_internal_javaRep_DIdentityStmt$sub_refs	_jc_soot_dava_internal_javaRep_DIdentityStmt$sub_refs;
typedef struct _jc_soot_dava_internal_javaRep_DIdentityStmt$sub_nonrefs	_jc_soot_dava_internal_javaRep_DIdentityStmt$sub_nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DIdentityStmt$refs	_jc_soot_dava_internal_javaRep_DIdentityStmt$refs;
typedef struct _jc_soot_dava_internal_javaRep_DIdentityStmt$nonrefs	_jc_soot_dava_internal_javaRep_DIdentityStmt$nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DIdentityStmt$object	_jc_soot_dava_internal_javaRep_DIdentityStmt$object;

typedef const struct _jc_soot_dava_internal_javaRep_DIdentityStmt$vmethods	_jc_soot_dava_internal_javaRep_DIdentityStmt$vmethods;
typedef const struct _jc_soot_dava_internal_javaRep_DIdentityStmt$vtable	_jc_soot_dava_internal_javaRep_DIdentityStmt$vtable;
typedef const struct _jc_soot_dava_internal_javaRep_DIdentityStmt$vtype	_jc_soot_dava_internal_javaRep_DIdentityStmt$vtype;

// Constructors
extern void _jc_soot_dava_internal_javaRep_DIdentityStmt$method$_init$b3c9ec81c7d0a5b0(_jc_env *, struct _jc_soot_dava_internal_javaRep_DIdentityStmt$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_dava_internal_javaRep_DIdentityStmt$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_dava_internal_javaRep_DIdentityStmt$object *) _JC_JCNI_ATTR;
extern void _jc_soot_dava_internal_javaRep_DIdentityStmt$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_dava_internal_javaRep_DIdentityStmt$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_javaRep_DIdentityStmt$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_dava_internal_javaRep_DIdentityStmt$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_dava_internal_javaRep_DIdentityStmt$vmethods {
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DIdentityStmt$object *) _JC_JCNI_ATTR;
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DIdentityStmt$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_dava_internal_javaRep_DIdentityStmt$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_jimple_internal_AbstractStmt$vmethods	soot_jimple_internal_AbstractStmt;
	_jc_soot_jimple_internal_AbstractDefinitionStmt$vmethods	soot_jimple_internal_AbstractDefinitionStmt;
	_jc_soot_jimple_internal_JIdentityStmt$vmethods	soot_jimple_internal_JIdentityStmt;
	_jc_soot_grimp_internal_GIdentityStmt$vmethods	soot_grimp_internal_GIdentityStmt;
	_jc_soot_dava_internal_javaRep_DIdentityStmt$vmethods	soot_dava_internal_javaRep_DIdentityStmt;
};

// Vtype
struct _jc_soot_dava_internal_javaRep_DIdentityStmt$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_javaRep_DIdentityStmt$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DIdentityStmt$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DIdentityStmt$refs {
    _jc_soot_dava_internal_javaRep_DIdentityStmt$sub_refs	soot_dava_internal_javaRep_DIdentityStmt;
    _jc_soot_grimp_internal_GIdentityStmt$sub_refs	soot_grimp_internal_GIdentityStmt;
    _jc_soot_jimple_internal_JIdentityStmt$sub_refs	soot_jimple_internal_JIdentityStmt;
    _jc_soot_jimple_internal_AbstractDefinitionStmt$sub_refs	soot_jimple_internal_AbstractDefinitionStmt;
    _jc_soot_jimple_internal_AbstractStmt$sub_refs	soot_jimple_internal_AbstractStmt;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DIdentityStmt$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DIdentityStmt$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_jimple_internal_AbstractStmt$sub_nonrefs	soot_jimple_internal_AbstractStmt;
    _jc_soot_jimple_internal_AbstractDefinitionStmt$sub_nonrefs	soot_jimple_internal_AbstractDefinitionStmt;
    _jc_soot_jimple_internal_JIdentityStmt$sub_nonrefs	soot_jimple_internal_JIdentityStmt;
    _jc_soot_grimp_internal_GIdentityStmt$sub_nonrefs	soot_grimp_internal_GIdentityStmt;
    _jc_soot_dava_internal_javaRep_DIdentityStmt$sub_nonrefs	soot_dava_internal_javaRep_DIdentityStmt;
};

// Object instance structure
struct _jc_soot_dava_internal_javaRep_DIdentityStmt$object {
	_jc_soot_dava_internal_javaRep_DIdentityStmt$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_javaRep_DIdentityStmt$vtype	*vtype;
	_jc_soot_dava_internal_javaRep_DIdentityStmt$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_javaRep_DIdentityStmt$vtype _jc_soot_dava_internal_javaRep_DIdentityStmt$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_javaRep_DIdentityStmt, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_javaRep_DIdentityStmt$class_object;

#endif	/* _JC_soot_dava_internal_javaRep_DIdentityStmt_H_ */
